@@ -2,9 +2,8 @@ from abc import ABC, abstractmethod
 from typing import TypeVar, Callable, Generic
 # from collections.abc import Callable
 
-from forbiddenfruit import curse
 
-from function import flip
+from grass.function import flip
 
 A = TypeVar('A')
 B = TypeVar('B')
@@ -22,14 +21,5 @@ def map(f: Callable[[A], B], fa: Functor[A]) -> Functor[B]:
     else:
         raise ValueError
 
-def list_fmap(self, f):
-    res = []
-    for x in self:
-        res.append(f(x))
-    return res
-
-curse(list, "fmap", list_fmap)
-
-Functor.register(list)
 
 mapFlipped = flip(map)
